@@ -30,8 +30,10 @@
 #include "add_standard_users.h"
 #include "functions.h"
 #include "show_info.h"
+#include "commands.h"
 
 extern int activated;
+extern int global_start_winbindd;
 
 
 
@@ -52,20 +54,7 @@ void activate_button_clicked(struct w *widgets)
     }
 
 
-// Moved to MAIN()....
-
-    /* Make sure we have the required standard users and groups */
-//    if( ! add_standard_users() )
-//    {
-//	printf("Error adding standard users and groups.\n");
-//	return;
-//    }
-
-
-
-    // FIXME .. use conf paths from settings.
-
-    // Use runlevel start scripts instead ???
+    // FIXME: Use conf paths from settings.
 
     /* Start SMBD */
     start = g_strdup_printf("%s -D -s %s", SMBD_BINARY, SAMBA_CONF);
@@ -76,6 +65,10 @@ void activate_button_clicked(struct w *widgets)
 	run_command_show_err(test);
 	g_free(test);
 	g_free(start);
+	
+	/* We dont want it started by init if its not working */
+	init_stop(widgets);
+	
 	return;
     }
     g_free(start);
@@ -94,16 +87,22 @@ void activate_button_clicked(struct w *widgets)
     }
     g_free(start);
 
-    /* Start WinBindD */
-    start = g_strdup_printf("%s -D -s %s", WINBINDD_BINARY, SAMBA_CONF);
-    if( ! run_command(start) )
+    /* We want it started by init at boot */
+    init_start(widgets);
+
+    /* Start WinBindD if the settings sais so */
+    if( global_start_winbindd )
     {
-        printf("Starting winbindd failed using this command: %s\nThe main SAMBA servers are working ok.\n", start);
-        test = g_strdup_printf("%s -D -s %s 2>&1", WINBINDD_BINARY, SAMBA_CONF);
-	run_command_show_err(test);
-	g_free(test);
-	g_free(start);
-	return;
+	start = g_strdup_printf("%s -D -s %s", WINBINDD_BINARY, SAMBA_CONF);
+	if( ! run_command(start) )
+	{
+    	    printf("Starting winbindd failed using this command: %s\nThe main SAMBA servers are working ok.\n", start);
+    	    test = g_strdup_printf("%s -D -s %s 2>&1", WINBINDD_BINARY, SAMBA_CONF);
+	    run_command_show_err(test);
+	    g_free(test);
+	    g_free(start);
+	    return;
+	}
+        g_free(start);
     }
-    g_free(start);
 }
