@@ -45,7 +45,7 @@ int smb_usermap_ok(gchar *path)
     long file_size;
     int valid_root = 0, valid_guest = 0;
     int retval = 0;
-    
+
     if((fp=fopen(path, "r"))==NULL)
     {
 	/* Dont show a dialog here */
@@ -78,7 +78,6 @@ int smb_usermap_ok(gchar *path)
 }
 
 
-
 int add_standard_users()
 {
     /* The sambamachines group and users NOBODY and smbguest accounts 
@@ -86,6 +85,85 @@ int add_standard_users()
     FILE *fp;
     gchar *cmd, *info, *path, *conf, *name;
 
+    /* SYSCONFDIR/samba is required */
+    cmd = g_strdup_printf("mkdir -p %s/samba", SYSCONFDIR);
+    if( ! run_command(cmd) )
+    {
+        printf("Error creating directory: %s/samba\n", SYSCONFDIR);
+        g_free(cmd);
+        return 0;
+    }
+    g_free(cmd);
+
+    /* SYSCONFDIR/samba/smbusers is required */
+    cmd = g_strdup_printf("touch %s/samba/smbusers", SYSCONFDIR);
+    if( ! run_command(cmd) )
+    {
+        printf("Error creating directory: %s/samba/smbusers\n", SYSCONFDIR);
+        g_free(cmd);
+        return 0;
+    }
+    g_free(cmd);
+
+    /* SYSCONFDIR/samba/smbpasswd is required */
+    cmd = g_strdup_printf("touch %s/samba/smbpasswd", SYSCONFDIR);
+    if( ! run_command(cmd) )
+    {
+        printf("Error creating directory: %s/samba/smbpasswd\n", SYSCONFDIR);
+        g_free(cmd);
+        return 0;
+    }
+    g_free(cmd);
+
+    /* SYSCONFDIR/samba/smb.conf is required */
+    cmd = g_strdup_printf("touch %s/samba/smb.conf", SYSCONFDIR);
+    if( ! run_command(cmd) )
+    {
+        printf("Error creating directory: %s/samba/smb.conf\n", SYSCONFDIR);
+        g_free(cmd);
+        return 0;
+    }
+    g_free(cmd);
+
+    /* SYSCONFDIR/samba/smbpasswd is required */
+    cmd = g_strdup_printf("touch %s/samba/smbpasswd", SYSCONFDIR);
+    if( ! run_command(cmd) )
+    {
+        printf("Error creating directory: %s/samba/smbpasswd\n", SYSCONFDIR);
+        g_free(cmd);
+        return 0;
+    }
+    g_free(cmd);
+
+    /* We want username mappings in /etc/samba/smbusers */
+    conf = g_strconcat(
+    "# Unix_name = SMB_Name1 SMB_Name2 ...\n",
+    "root = administrator\n",
+    "nobody = guest smbguest pcguest\n",
+    NULL);
+
+    path = g_strdup_printf("%s", SAMBA_USERMAP);    
+    if( ! file_exists(path) || ! smb_usermap_ok(path) )
+    {
+	if((fp=fopen(path, "w+"))==NULL)
+	{
+    	    info = g_strdup_printf(_("Failed adding default smbusers file here:\n%s\n"), SAMBA_USERMAP);
+    	    show_info(info);
+    	    g_free(info);
+
+    	    g_free(path);
+    	    g_free(conf);
+    	    return 0;
+	}
+	fputs(conf, fp);
+	fclose(fp);
+
+    	info = g_strdup_printf(_("A new smbusers map file was added here:\n%s\n It has the following contents: \"root = administrator\" and \"nobody = smbguest\".\n"), SAMBA_USERMAP);
+    	show_info(info);
+    	g_free(info);
+    }
+    g_free(path);
+    g_free(conf);    
 
     /* Add the NOBODY system group if it doesnt exist */
     name = g_strdup_printf("%s", NOBODY);
@@ -104,7 +182,6 @@ int add_standard_users()
     }
     g_free(name);
     
-
     /* Add the NOBODY system user to the NOBODY group as a locked account */
     name = g_strdup_printf("%s", NOBODY);
     if( ! user_exists(name) )
@@ -137,7 +214,7 @@ int add_standard_users()
     name = g_strdup_printf("%s", "smbguest");
     if( ! user_exists(name) )
     {
-        /* Add the user to the NOBODY group */
+        /* Add the system user to the NOBODY group */
         cmd = g_strdup_printf("%s '%s' -d /dev/null -c 'Samba guest account' -s /dev/null -g '%s'", "useradd", name, NOBODY);
         if( ! run_command(cmd) )
         {
@@ -184,7 +261,6 @@ int add_standard_users()
     g_free(name);
 
 
-
     /* The sambamachines account also needs to exist in order to automatically 
        add valid(username+password) connecting computers BIOS-id's as computer accounts */
     name = g_strdup_printf("%s", "sambamachines");
@@ -225,39 +301,5 @@ int add_standard_users()
     }
     g_free(name);
 
-
-
-    /* We want to have username mappings in /etc/samba/smbusers */
-    conf = g_strconcat(
-    "# Unix_name = SMB_Name1 SMB_Name2 ...\n",
-    "root = administrator\n",
-    "nobody = guest smbguest pcguest\n",
-    NULL);
-
-    path = g_strdup_printf("%s", SAMBA_USERMAP);    
-
-    if( ! file_exists(path) || ! smb_usermap_ok(path) )
-    {
-	if((fp=fopen(path, "w+"))==NULL)
-	{
-    	    info = g_strdup_printf(_("Failed adding default smbusers file here:\n%s\n"), SAMBA_USERMAP);
-    	    show_info(info);
-    	    g_free(info);
-
-    	    g_free(path);
-    	    g_free(conf);
-    	    return 0;
-	}
-	fputs(conf, fp);
-	fclose(fp);
-
-    	info = g_strdup_printf(_("A new smbusers map file was added here:\n%s\n\"root = administrator\" and \"nobody = smbguest\" must be in it\n"), SAMBA_USERMAP);
-    	show_info(info);
-    	g_free(info);
-    }
-
-    g_free(path);
-    g_free(conf);    
-
     return 1;
 }
