@@ -19,14 +19,14 @@
 
 
 
-
 #ifndef commands_H
 #	define commands_H
 
 int run_command(gchar *command);
 void run_command_show_err(gchar *command);
-//void show_info(char *content);
 int file_exists(char *infile);
 int using_tls(void);
+void init_start(struct w *widgets);
+void init_stop(struct w *widgets);
 
 #endif
