@@ -27,6 +27,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
+#include <ctype.h>
 #include <time.h>
 #include "widgets.h"
 #include "chars_are_digits.h"
@@ -49,6 +50,224 @@
 #endif
 
 
+/* Compare strings in lower case */
+int cmplowercase(char *buf, char *cmpstring)
+{
+    char *p, *newbuf;
+    int retval = 0;
+
+    if( buf==NULL )
+      return retval;
+
+    /* Ignore single newline chars */
+    if( strlen(buf) < 2 )
+      return retval;
+
+    newbuf = allocate(strlen(buf)+1);
+    /* Exists if it cant allocate */
+    sprintf(newbuf, "%s", buf);
+
+    for(p = newbuf; *p!='\0'; ++p)
+        *p = tolower(*p);
+
+    if( strstr(newbuf, cmpstring) )
+      retval = 1;
+
+    free(newbuf);
+
+    return retval;
+}
+
+
+/* Transform a string to lower case.
+char *lowercase(char *buf) 
+{
+    char *p;
+    if( buf==NULL || strlen(buf)<2 )
+      return buf;
+    for(p = buf; *p!='\0'; ++p)
+        *p = tolower(*p);
+    return buf;
+}
+*/
+
+
+void
+add_global_option(char *option)
+{
+    /* Adds a global option if it doesnt exist */
+    FILE *fp;
+    char *line;
+    char *new_buffer;
+    long conf_size;
+    int option_existed = 0;
+    gchar *option1, *option2;
+
+    /* To ways to identify an option and avoid mixups */    
+    option1 = g_strdup_printf("%s=", option);
+    option2 = g_strdup_printf("%s =", option);
+
+    if( option==NULL || strlen(option)<3 )
+    {
+	printf("Add global option: Option length too short.\n");
+	return;
+    }
+
+    if((fp=fopen(SAMBA_CONF, "r"))==NULL)    
+    {
+	printf("Cant open: %s\n", SAMBA_CONF);
+	return;
+    }
+
+    fseek(fp, 0, SEEK_END);
+    conf_size = ftell(fp);
+    rewind(fp);
+
+    new_buffer = allocate(conf_size+4096);
+    line = allocate(conf_size+1);
+
+    /* Dont add a new option if it already exists */
+    while(fgets(line, conf_size, fp)!=NULL)
+    {
+	if( (cmplowercase(line, option1) || cmplowercase(line, option2))
+	&& ! commented(line) )
+	{
+	    option_existed = 1;
+	    break;
+	}
+    }
+
+    g_free(option1);
+    g_free(option2);
+
+    if( option_existed )
+    {
+	fclose(fp);
+	free(new_buffer);
+	free(line);
+	return;
+    }
+
+
+    rewind(fp);
+
+    /* Get everything up to and including "[global]" or the first option "=" */
+    while(fgets(line, conf_size, fp)!=NULL)
+    {
+	strcat(new_buffer, line);
+	
+	if( cmplowercase(line, "[global]") && ! commented(line) )
+	  break;
+
+	if( cmplowercase(line, "=") && ! commented(line) )
+	  break;
+    }
+
+    /* Add the new option */
+    strcat(new_buffer, option);
+    strcat(new_buffer, " =\n");
+
+    while(fgets(line, conf_size, fp)!=NULL)
+	strcat(new_buffer, line);
+
+    fclose(fp);
+
+    /* Write the new conf */
+    if((fp=fopen(SAMBA_CONF, "w+"))==NULL)    
+    {
+	printf("Cant write to: %s\n", SAMBA_CONF);
+	return;
+    }
+    fputs(new_buffer, fp);
+    fclose(fp);
+
+    free(line);
+    free(new_buffer);
+}
+
+
+void
+remove_global_option(char *option)
+{
+    FILE *fp;
+    char *line;
+    char *new_buffer;
+    long conf_size;
+    gchar *option1, *option2;
+
+    /* To ways to identify an option and avoid mixups */    
+    option1 = g_strdup_printf("%s=", option);
+    option2 = g_strdup_printf("%s =", option);
+
+
+    if( option==NULL || strlen(option)<3 )
+    {
+	printf("Remove global option: Option length too short.\n");
+	g_free(option1);
+	g_free(option2);
+	return;
+    }
+
+    if((fp=fopen(SAMBA_CONF, "r"))==NULL)    
+    {
+	printf("Cant open: %s\n", SAMBA_CONF);
+	g_free(option1);
+	g_free(option2);
+	return;
+    }
+    fseek(fp, 0, SEEK_END);
+    conf_size = ftell(fp);
+    rewind(fp);
+
+    new_buffer = allocate(conf_size+4096);
+    line = allocate(conf_size+1);
+
+    /* Get everything up to and including the first
+       share definition "[" and skips the option */
+    while(fgets(line, conf_size, fp)!=NULL)
+    {
+	/* Break at any share definition */
+	if( strstr(line, "[") && ! cmplowercase(line, "[global]")
+	&& ! commented(line) )
+	{
+	    strcat(new_buffer, line);
+	    break;
+	}
+
+	/* Skip the specified option. */
+	if( (cmplowercase(line, option1) || cmplowercase(line, option2))
+	&& ! commented(line) )
+	{
+	    printf("Removed option: %s\n", option);
+	    continue;
+	}
+	else
+	    strcat(new_buffer, line);
+    }
+
+    g_free(option1);
+    g_free(option2);
+
+    /* Gather the rest */
+    while(fgets(line, conf_size, fp)!=NULL)
+	strcat(new_buffer, line);
+
+    fclose(fp);
+
+    /* Write the new conf */
+    if((fp=fopen(SAMBA_CONF, "w+"))==NULL)    
+    {
+	printf("Cant write to: %s\n", SAMBA_CONF);
+	return;
+    }
+    fputs(new_buffer, fp);
+    fclose(fp);
+
+    free(line);
+    free(new_buffer);
+}
+
+
 int
 smbuser_exists(G_CONST_RETURN gchar *username)
 {
@@ -892,13 +1111,12 @@ void randomize_username(struct w *widgets)
       g_free(utf8);
 
 
-
     /* Insert the randomized username after the path in the homedir entry */    
     homedir_username = allocate(16384);
     default_homedir = allocate(16384);
 
 //    default_homedir = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[4]));
-// Fixme.. get from settings
+// Fixme.. get from gsambad settings
     snprintf(default_homedir, 8190, "%s", "/home");
     if( strlen((char *)default_homedir) > 8192 )
     {
@@ -1107,7 +1325,3 @@ exec_ssl(char *command, char descr[128])
     }
     pclose(fp);
 }
-
-
-
-
