@@ -30,18 +30,28 @@ int get_option_pos(char *line)
 {
     long i=0;
 
+    /* Locate the position at "=" + 1 */
     if( line!=NULL && strlen(line) > 0 )
     {
 	for(i=0; line[i]!='\0'; i++)
 	{
-	    /* Skip whitespace up to '=' */
 	    if( line[i]=='=' )
+	    {
+		i++;
+	        break;
+	    }
+	}
+    }
+
+    /* Locate the position of the first char after "=" */
+    if( line!=NULL && strlen(line) > 0 )
+    {
+	for(i=i; line[i]!='\0'; i++)
+	{
+	    if( line[i]!=' ' )
 	      break;
 	}
     }
-    /* Skip '=' and a whitespace.
-       Should be another for() to be perfect but it doesnt matter */
-    i=i+2;
 
     return i;
 }
