@@ -49,19 +49,24 @@
 #include "create_conf_tab.h"
 #include "populate_gsambad.h"
 #include "show_info.h"
+#include "load_settings.h"
 #include "status_update.h"
 
 int MAX_READ_POPEN = 16384;
 int activated = 0;
+int global_smbd_activated = 0;
+int global_nmbd_activated = 0;
+int global_winbindd_activated = 0;
+
+/* Wether or not to start winbindd */
+int global_start_winbindd = 1;
 
 int info_window_exit_main = 0;
 
 char global_user_name[1024]="";
 char global_share_name[16384]="";
-
 char global_macct_name[1024]="";
 
-
 /* Default values for the importer */
 int global_import_local  = 1;
 int global_import_remote = 0;
@@ -118,6 +123,10 @@ int main(int argc, char *argv[])
 	return 0;
     }
 
+    /* Add standard users (nobody etc) also makes sure
+       that we have sambas configuration directory and required files */
+    add_standard_users(widgets);
+
 
     /* Create the main window */
     create_main_window(widgets);
@@ -137,21 +146,16 @@ int main(int argc, char *argv[])
     /* Create the user settings */
     create_user_settings(widgets);
 
-
     /* Create the share tab */
     create_share_tab(widgets);
     create_share_settings(widgets);
 
-
     /* Create the machine account tab */
     create_macct_tab(widgets);
     create_macct_settings(widgets);
 
     /* Create the connection tab */
     create_conn_tab(widgets);
-// FIXME   create_conn_settings(widgets);
-
-
 
     /* Create the disc tab */
     create_disc_tab(widgets);
@@ -162,21 +166,21 @@ int main(int argc, char *argv[])
     /* Create the conf tab */
     create_conf_tab(widgets);
 
+    /* Load settings from gsambads settings file */
+    load_settings(widgets);
 
-    /* Add standard users (nobody etc) */
-    add_standard_users(widgets);
-
-
-
-//FIXME    conf_path = g_strdup_printf("%s/smb.conf", SAMBA_CONF_BUF);
     conf_path = g_strdup_printf("%s", SAMBA_CONF);
     gsambad_settings = g_strdup_printf("%s", SETTINGS_FILE);
 
     /* If theres no smb.conf, add one and populate the entire gui */
     if( ! file_exists(conf_path) )
-      add_standard_conf(widgets);
+    {
+        add_standard_conf(widgets);
+        populate_gsambad(widgets);
+    }
     else      
-    /* If we havnt asked to add an smb.conf file, then ask (show_conf_question: in gsambad's settings) */
+    /* Ask to add a new conf if we havnt done so before. 
+       Depends on show_conf_question: yes/no in gsambad's settings */
     if( ! conf_ok(gsambad_settings) )
       create_standard_conf_question(widgets);
     else
