@@ -32,7 +32,7 @@
 #include "commented.h"
 #include "get_option_pos.h"
 #include "show_info.h"
-
+#include "functions.h"
 
 
 void populate_server_settings(struct w *widgets)
@@ -45,7 +45,6 @@ void populate_server_settings(struct w *widgets)
     char *line, *new_buffer;
     gchar *info, *utf8 = NULL;
 
-
     if((fp=fopen(SAMBA_CONF, "r"))==NULL)
     {
 	info = g_strdup_printf(_("Cant open smb.conf here:\n%s\n"), SAMBA_CONF);
@@ -64,39 +63,42 @@ void populate_server_settings(struct w *widgets)
     if( conf_size > 1 )
     while(fgets(line, conf_size, fp)!=NULL)
     {
+	if( commented(line) )
+	  continue;
+
 	/* Break at any share definition */
-	if( strstr(line, "[") && ! strstr(line, "[global]") && ! commented(line) )
+	if( strstr(line, "[") && ! cmplowercase(line, "[global]") )
 	  break;
 	
 	/* Security is user */
-	if( strstr(line, "security = ") && (strstr(line, "user") || strstr(line, "User"))
-	&& ! commented(line) ) 
+	if( cmplowercase(line, "security = ") && cmplowercase(line, "user") )
 	  is_user = 1;
     }
     rewind(fp);
 
-    /* We know that security is user, now see if its a BDC, set as: is_bdc */    
+    /* We know that security is USER, now see if its a BDC, set as: is_bdc */    
     if( is_user && conf_size > 1 )
     while(fgets(line, conf_size, fp)!=NULL)
     {
+	if( commented(line) )
+	  continue;
+
 	/* Break at any share definition */
-	if( strstr(line, "[") && ! strstr(line, "[global]") && ! commented(line) )
+	if( strstr(line, "[") && ! cmplowercase(line, "[global]") )
 	  break;
 	
 	/* If domain logons is specified its a BDC */
-	if( strstr(line, "domain logons = ") && (strstr(line, "true") || strstr(line, "yes"))
-	&& ! commented(line) ) 
+	if( cmplowercase(line, "domain logons = ") && cmplowercase(line, "yes") ) 
 	  is_bdc = 1;
     }
     rewind(fp);
 
 
-
     /* First scroll to the global section */
     if( conf_size > 1 )
     while(fgets(line, conf_size, fp)!=NULL)
     {
-	if( strstr(line, "[global]") && ! commented(line) )
+	if( cmplowercase(line, "[global]") && ! commented(line) )
 	{
 	    global_section_found = 1;
 	    break;
@@ -118,16 +120,22 @@ void populate_server_settings(struct w *widgets)
     if( conf_size > 1 )
     while(fgets(line, conf_size, fp)!=NULL)
     {
-	/* Break at any share definition "[" and collect them in the next while loop */
-	if( strstr(line, "[") && ! commented(line) )
+	/* Scroll past any comment */
+	if( commented(line) )
+	  continue;
+
+	/* Break at any share definition "[" */
+	if( strstr(line, "[") )
 	   break;
 
+
 	/* Entries... */
 
-	/* Change matching server directives otherwise just gather them */
-	if( strstr(line, "netbios name") && ! commented(line) )
+	/* Populate matching server directives */
+	if( cmplowercase(line, "netbios name") )
 	{
-	    opt_pos = get_option_pos(line); /* positions are at: "="+1 */
+	    /* Positions are at the first char located after "=" not including whitespace */
+	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
 	      new_buffer[strlen(new_buffer)-1]='\0';
@@ -136,7 +144,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[0]), utf8);
 	}
 	else
-	if( strstr(line, "server string") && ! commented(line) )
+	if( cmplowercase(line, "server string") )
     	{          	
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -147,7 +155,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[1]), utf8);
 	}
 	else
-	if( strstr(line, "workgroup") && ! commented(line) )
+	if( cmplowercase(line, "workgroup") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -158,7 +166,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[2]), utf8);
 	}
 	else
-	if( strstr(line, "hosts allow") && ! commented(line) )
+	if( cmplowercase(line, "realm") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -169,7 +177,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[3]), utf8);
 	}
 	else
-	if( strstr(line, "interfaces") && ! commented(line) )
+	if( cmplowercase(line, "hosts allow") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -180,7 +188,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[4]), utf8);
 	}
 	else
-	if( strstr(line, "remote announce") && ! commented(line) )
+	if( cmplowercase(line, "interfaces") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -191,7 +199,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[5]), utf8);
 	}
 	else
-	if( strstr(line, "remote browse sync") && ! commented(line) )
+	if( cmplowercase(line, "remote announce") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -202,7 +210,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[6]), utf8);
 	}
 	else
-	if( strstr(line, "printcap name") && ! commented(line) )
+	if( cmplowercase(line, "remote browse sync") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -213,7 +221,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[7]), utf8);
 	}
 	else
-	if( strstr(line, "guest account") && ! commented(line) )
+	if( cmplowercase(line, "printcap name") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -224,7 +232,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[8]), utf8);
 	}
 	else
-	if( strstr(line, "log file") && ! commented(line) )
+	if( cmplowercase(line, "guest account") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -235,7 +243,18 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[9]), utf8);
 	}
 	else
-	if( strstr(line, "username map") && ! commented(line) )
+	if( cmplowercase(line, "log file") )
+	{
+	    opt_pos = get_option_pos(line);
+	    sprintf(new_buffer, "%s", &line[opt_pos]);
+	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
+	      new_buffer[strlen(new_buffer)-1]='\0';
+
+	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
+            gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[10]), utf8);
+	}
+	else
+	if( cmplowercase(line, "socket options") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -246,7 +265,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[11]), utf8);
 	}
 	else
-	if( strstr(line, "add user script") && ! commented(line) )
+	if( cmplowercase(line, "logon drive") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -257,7 +276,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[12]), utf8);
 	}
 	else
-	if( strstr(line, "smb passwd file") && ! commented(line) )
+	if( cmplowercase(line, "logon home") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -268,7 +287,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[13]), utf8);
 	}
 	else
-	if( strstr(line, "passwd program") && ! commented(line) )
+	if( cmplowercase(line, "logon path") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -279,7 +298,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[14]), utf8);
 	}
 	else
-	if( strstr(line, "passwd chat") && ! commented(line) )
+	if( cmplowercase(line, "logon script") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -290,7 +309,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[15]), utf8);
 	}
 	else
-	if( strstr(line, "socket options") && ! commented(line) )
+	if( cmplowercase(line, "name resolve order") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -301,7 +320,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[16]), utf8);
 	}
 	else
-	if( strstr(line, "logon drive") && ! commented(line) )
+	if( cmplowercase(line, "wins server") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -312,7 +331,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[17]), utf8);
 	}
 	else
-	if( strstr(line, "logon home") && ! commented(line) )
+	if( cmplowercase(line, "username map") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -323,7 +342,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[18]), utf8);
 	}
 	else
-	if( strstr(line, "logon path") && ! commented(line) )
+	if( cmplowercase(line, "smb passwd file") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -334,7 +353,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[19]), utf8);
 	}
 	else
-	if( strstr(line, "logon script") && ! commented(line) )
+	if( cmplowercase(line, "passwd program") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -345,18 +364,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[20]), utf8);
 	}
 	else
-	if( strstr(line, "name resolve order") && ! commented(line) )
-	{
-	    opt_pos = get_option_pos(line);
-	    sprintf(new_buffer, "%s", &line[opt_pos]);
-	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
-	      new_buffer[strlen(new_buffer)-1]='\0';
-
-	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
-            gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[21]), utf8);
-	}
-	else
-	if( strstr(line, "wins server") && ! commented(line) )
+	if( cmplowercase(line, "passwd chat") && ! cmplowercase(line, "passwd chat timeout") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -367,7 +375,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[22]), utf8);
 	}
 	else
-	if( strstr(line, "idmap uid") && ! commented(line) )
+	if( cmplowercase(line, "add user script") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -378,7 +386,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[23]), utf8);
 	}
 	else
-	if( strstr(line, "idmap gid") && ! commented(line) )
+	if( cmplowercase(line, "add user to group script") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -389,7 +397,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[24]), utf8);
 	}
 	else
-	if( strstr(line, "template shell") && ! commented(line) )
+	if( cmplowercase(line, "add group script") )
 	{
 	    opt_pos = get_option_pos(line);
 	    sprintf(new_buffer, "%s", &line[opt_pos]);
@@ -400,172 +408,472 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[25]), utf8);
 	}
 	else
+	if( cmplowercase(line, "delete user script") )
+	{
+	    opt_pos = get_option_pos(line);
+	    sprintf(new_buffer, "%s", &line[opt_pos]);
+	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
+	      new_buffer[strlen(new_buffer)-1]='\0';
+
+	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
+            gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[26]), utf8);
+	}
+	else
+
+	if( cmplowercase(line, "delete user from group script") )
+	{
+	    opt_pos = get_option_pos(line);
+	    sprintf(new_buffer, "%s", &line[opt_pos]);
+	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
+	      new_buffer[strlen(new_buffer)-1]='\0';
+
+	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
+            gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[27]), utf8);
+	}
+	else
+
+	if( cmplowercase(line, "delete group script") )
+	{
+	    opt_pos = get_option_pos(line);
+	    sprintf(new_buffer, "%s", &line[opt_pos]);
+	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
+	      new_buffer[strlen(new_buffer)-1]='\0';
+
+	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
+            gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[28]), utf8);
+	}
+	else
+	if( cmplowercase(line, "add machine script") )
+	{
+	    opt_pos = get_option_pos(line);
+	    sprintf(new_buffer, "%s", &line[opt_pos]);
+	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
+	      new_buffer[strlen(new_buffer)-1]='\0';
+
+	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
+            gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[29]), utf8);
+	}
+	else
+
+
+/* Didnt seem to work	if( cmplowercase(line, "root directory") )
+	{
+	    opt_pos = get_option_pos(line);
+	    sprintf(new_buffer, "%s", &line[opt_pos]);
+	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
+	      new_buffer[strlen(new_buffer)-1]='\0';
+
+	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
+            gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[21]), utf8);
+	}
+	else
+*/
+	if( cmplowercase(line, "idmap uid") )
+	{
+	    opt_pos = get_option_pos(line);
+	    sprintf(new_buffer, "%s", &line[opt_pos]);
+	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
+	      new_buffer[strlen(new_buffer)-1]='\0';
+
+	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
+            gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[30]), utf8);
+	}
+	else
+	if( cmplowercase(line, "idmap gid") )
+	{
+	    opt_pos = get_option_pos(line);
+	    sprintf(new_buffer, "%s", &line[opt_pos]);
+	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
+	      new_buffer[strlen(new_buffer)-1]='\0';
+
+	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
+            gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[31]), utf8);
+	}
+	else
+	if( cmplowercase(line, "template shell") )
+	{
+	    opt_pos = get_option_pos(line);
+	    sprintf(new_buffer, "%s", &line[opt_pos]);
+	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
+	      new_buffer[strlen(new_buffer)-1]='\0';
+
+	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
+            gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[32]), utf8);
+	}
+	else
+	if( cmplowercase(line, "winbind separator") )
+	{
+	    opt_pos = get_option_pos(line);
+	    sprintf(new_buffer, "%s", &line[opt_pos]);
+	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
+	      new_buffer[strlen(new_buffer)-1]='\0';
+
+	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
+            gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[33]), utf8);
+	}
+	else
+
 
 
 	/* Combos... */
-
 	
-	/* Security level */
-    	if( strstr(line, "security") && ! commented(line) )
+
+	/* Security level, also sets realm usability */
+    	if( cmplowercase(line, "security") )
 	{
 	    /* User */
-	    if( ! is_bdc && (strstr(line, "User") || strstr(line, "user")) )
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[0]), 0);
+	    if( ! is_bdc && cmplowercase(line, "user") )
+	    {
+	        gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[0]), 0);
+
+		/* Clear Realm entry, disable input and remove the option */
+		gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[3]), "");
+		gtk_widget_set_sensitive(GTK_WIDGET(widgets->server_set_entry[3]), 0);
+	    }
 	    else /* BDC */
-	    if( is_bdc && (strstr(line, "User") || strstr(line, "user")) ) 
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[0]), 1);
+	    if( is_bdc && cmplowercase(line, "user") ) 
+	    {
+	        gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[0]), 1);
+
+		/* Can realm be used here ? */
+		gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[3]), "");
+		gtk_widget_set_sensitive(GTK_WIDGET(widgets->server_set_entry[3]), 0);
+	    }
 	    else
-	    if( strstr(line, "Domain") || strstr(line, "domain") )
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[0]), 2);
+	    if( cmplowercase(line, "domain") )
+	    {
+	        gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[0]), 2);
+
+		/* Can realm be used here ? */
+		gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[3]), "");
+		gtk_widget_set_sensitive(GTK_WIDGET(widgets->server_set_entry[3]), 0);
+	    }
 	    else /* ADS */
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[0]), 3);
+	    {
+	        gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[0]), 3);
+
+		/* Enable Kerberos Realm entry (Disabled in apply server settings) */
+		gtk_widget_set_sensitive(GTK_WIDGET(widgets->server_set_entry[3]), 1);
+	    }
 	}
 	else
-    	if( strstr(line, "load printers") && ! commented(line) )
+    	if( cmplowercase(line, "load printers") )
 	{
-	    if( strstr(line, "yes") )
+	    if( cmplowercase(line, "yes") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[1]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[1]), 1);
 	}
 	else
-    	if( strstr(line, "cups options") && ! commented(line) )
+    	if( cmplowercase(line, "cups options") )
 	{
-	    if( strstr(line, "raw") || strstr(line, "Raw") || strstr(line, "RAW") )
+	    if( cmplowercase(line, "raw") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[2]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[2]), 1);
 	}
 	else
-    	if( strstr(line, "null passwords") && ! commented(line) )
+
+// printing = cups missing, dunno what extra options it has.
+
+    	if( cmplowercase(line, "null passwords") )
 	{
-	    if( strstr(line, "yes") )
+	    if( cmplowercase(line, "yes") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[3]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[3]), 1);
 	}
 	else
-	if( strstr(line, "encrypt passwords") && ! commented(line) )
+	if( cmplowercase(line, "encrypt passwords") )
 	{
-	    if( strstr(line, "yes") )
+	    if( cmplowercase(line, "yes") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[4]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[4]), 1);
 	}
 	else
-    	if( strstr(line, "unix password sync") && ! commented(line) )
+    	if( cmplowercase(line, "unix password sync") )
 	{
-	    if( strstr(line, "yes") )
+	    if( cmplowercase(line, "yes") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[5]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[5]), 1);
 	}
 	else
-    	if( strstr(line, "local master") && ! commented(line) )
+    	if( cmplowercase(line, "local master") )
 	{
-	    if( strstr(line, "yes") )
+	    if( cmplowercase(line, "yes") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[6]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[6]), 1);
 	}
 	else
-    	if( strstr(line, "domain master") && ! commented(line) )
+    	if( cmplowercase(line, "domain master") )
 	{
-	    if( strstr(line, "yes") )
+	    if( cmplowercase(line, "yes") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[7]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[7]), 1);
 	}
 	else
-    	if( strstr(line, "preferred master") && ! commented(line) )
+    	if( cmplowercase(line, "preferred master") )
 	{
-	    if( strstr(line, "yes") )
+	    if( cmplowercase(line, "yes") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[8]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[8]), 1);
 	}
 	else
-    	if( strstr(line, "time server") && ! commented(line) )
+    	if( cmplowercase(line, "domain logons") )
 	{
-	    if( strstr(line, "yes") )
+	    if( cmplowercase(line, "yes") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[9]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[9]), 1);
 	}
 	else
-    	if( strstr(line, "domain logons") && ! commented(line) )
+    	if( cmplowercase(line, "time server") )
 	{
-	    if( strstr(line, "yes") )
+	    if( cmplowercase(line, "yes") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[10]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[10]), 1);
 	}
 	else
-    	if( strstr(line, "wins support") && ! commented(line) )
+    	if( cmplowercase(line, "wins support") )
 	{
-	    if( strstr(line, "yes") )
+	    if( cmplowercase(line, "yes") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[11]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[11]), 1);
 	}
 	else
-    	if( strstr(line, "wins proxy") && ! commented(line) )
+    	if( cmplowercase(line, "wins proxy") )
 	{
-	    if( strstr(line, "yes") )
+	    if( cmplowercase(line, "yes") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[12]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[12]), 1);
 	}
 	else
-    	if( strstr(line, "dns proxy") && ! commented(line) )
+    	if( cmplowercase(line, "dns proxy") )
 	{
-	    if( strstr(line, "yes") )
+	    if( cmplowercase(line, "yes") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[13]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[13]), 1);
 	}
 	else
-    	if( strstr(line, "preserve case") && ! commented(line) )
+    	if( cmplowercase(line, "preserve case") )
 	{
-	    if( strstr(line, "yes") )
+	    if( cmplowercase(line, "yes") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[14]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[14]), 1);
 	}
 	else
-    	if( strstr(line, "winbind use default domain") && ! commented(line) )
+    	if( cmplowercase(line, "client use spnego") )
 	{
-	    if( strstr(line, "yes") )
+	    if( cmplowercase(line, "yes") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[15]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[15]), 1);
 	}
 	else
+    	if( cmplowercase(line, "client signing") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[16]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[16]), 1);
+	}
+	else
+    	if( cmplowercase(line, "client schannel") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[17]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[17]), 1);
+	}
+	else
+    	if( cmplowercase(line, "server signing") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[18]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[18]), 1);
+	}
+	else
+    	if( cmplowercase(line, "server schannel") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[19]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[19]), 1);
+	}
+	else
+    	if( cmplowercase(line, "nt pipe support") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[20]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[20]), 1);
+	}
+	else
+    	if( cmplowercase(line, "nt status support") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[21]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[21]), 1);
+	}
+	else
+    	if( cmplowercase(line, "allow trusted domains") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[22]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[22]), 1);
+	}
+	else
+    	if( cmplowercase(line, "obey pam restrictions") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[23]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[23]), 1);
+	}
+	else
+    	if( cmplowercase(line, "enable spoolss") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[24]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[24]), 1);
+	}
+	else
+    	if( cmplowercase(line, "client plaintext auth") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[25]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[25]), 1);
+	}
+	else
+    	if( cmplowercase(line, "disable netbios") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[26]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[26]), 1);
+	}
+	else
+    	if( cmplowercase(line, "follow symlinks") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[27]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[27]), 1);
+	}
+	else
+    	if( cmplowercase(line, "update encrypted") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[28]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[28]), 1);
+	}
+	else
+    	if( cmplowercase(line, "pam password change") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[29]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[29]), 1);
+	}
+	else
+    	if( cmplowercase(line, "hostname lookups") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[30]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[30]), 1);
+	}
+	else
+    	if( cmplowercase(line, "winbind use default domain") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[31]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[31]), 1);
+	}
+	else
+    	if( cmplowercase(line, "winbind trusted domains only") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[32]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[32]), 1);
+	}
+	else
+    	if( cmplowercase(line, "winbind nested groups") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[33]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[33]), 1);
+	}
+	else
+    	if( cmplowercase(line, "winbind nss info") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[34]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[34]), 1);
+	}
+	else
+    	if( cmplowercase(line, "winbind refresh tickets") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[35]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[35]), 1);
+	}
+	else
+    	if( cmplowercase(line, "winbind offline logon") )
+	{
+	    if( cmplowercase(line, "yes") )
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[36]), 0);
+	    else
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[36]), 1);
+	}
+	else
 
 
 	/* Spinbuttons... */
 
 
-    	if( strstr(line, "max log size") && ! commented(line) )
+    	if( cmplowercase(line, "max log size") )
 	{
-	    new_buffer[0]='\0';
-	    sscanf(line, "%*s %*s %*s %*s %s", new_buffer);
+	    opt_pos = get_option_pos(line);
+	    sprintf(new_buffer, "%s", &line[opt_pos]);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
 	      new_buffer[strlen(new_buffer)-1]='\0';
+
 	    if( chars_are_digits(new_buffer) )
 	    {
         	val = atoi(new_buffer);
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[0]), val);
 	    }
-
 	}
 	else
-    	if( strstr(line, "username level") && ! commented(line) )
+    	if( cmplowercase(line, "username level") )
 	{
-	    new_buffer[0]='\0';
-	    sscanf(line, "%*s %*s %*s %s", new_buffer);
+	    opt_pos = get_option_pos(line);
+	    sprintf(new_buffer, "%s", &line[opt_pos]);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
 	      new_buffer[strlen(new_buffer)-1]='\0';
+
 	    if( chars_are_digits(new_buffer) )
 	    {
         	val = atoi(new_buffer);
@@ -573,12 +881,13 @@ void populate_server_settings(struct w *widgets)
 	    }
 	}
 	else
-    	if( strstr(line, "password level") && ! commented(line) )
+    	if( cmplowercase(line, "password level") )
 	{
-	    new_buffer[0]='\0';
-	    sscanf(line, "%*s %*s %*s %s", new_buffer);
+	    opt_pos = get_option_pos(line);
+	    sprintf(new_buffer, "%s", &line[opt_pos]);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
 	      new_buffer[strlen(new_buffer)-1]='\0';
+
 	    if( chars_are_digits(new_buffer) )
 	    {
         	val = atoi(new_buffer);
@@ -586,18 +895,61 @@ void populate_server_settings(struct w *widgets)
 	    }
 	}
 	else
-    	if( strstr(line, "os level") && ! commented(line) )
+    	if( cmplowercase(line, "os level") )
 	{
-	    new_buffer[0]='\0';
-	    sscanf(line, "%*s %*s %*s %s", new_buffer);
+	    opt_pos = get_option_pos(line);
+	    sprintf(new_buffer, "%s", &line[opt_pos]);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
 	      new_buffer[strlen(new_buffer)-1]='\0';
+
 	    if( chars_are_digits(new_buffer) )
 	    {
         	val = atoi(new_buffer);
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[3]), val);
 	    }
 	}
+	else
+	if( cmplowercase(line, "passwd chat timeout") )
+	{
+	    opt_pos = get_option_pos(line);
+	    sprintf(new_buffer, "%s", &line[opt_pos]);
+	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
+	      new_buffer[strlen(new_buffer)-1]='\0';
+
+	    if( chars_are_digits(new_buffer) )
+	    {
+        	val = atoi(new_buffer);
+        	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[4]), val);
+	    }
+	}
+	else
+    	if( cmplowercase(line, "machine password timeout") )
+	{
+	    opt_pos = get_option_pos(line);
+	    sprintf(new_buffer, "%s", &line[opt_pos]);
+	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
+	      new_buffer[strlen(new_buffer)-1]='\0';
+
+	    if( chars_are_digits(new_buffer) )
+	    {
+        	val = atoi(new_buffer);
+        	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[5]), val);
+	    }
+	}
+	else
+    	if( cmplowercase(line, "winbind cache time") )
+	{
+	    opt_pos = get_option_pos(line);
+	    sprintf(new_buffer, "%s", &line[opt_pos]);
+	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
+	      new_buffer[strlen(new_buffer)-1]='\0';
+
+	    if( chars_are_digits(new_buffer) )
+	    {
+        	val = atoi(new_buffer);
+        	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[6]), val);
+	    }
+	}
     }
     fclose(fp);
     free(line);
