@@ -18,7 +18,6 @@
 */
 
 
-
 #include "../config.h"
 #include <gtk/gtk.h>
 #include "gettext.h"
@@ -29,39 +28,45 @@
 #include "widgets.h"
 #include "functions.h"
 #include "commands.h"
+#include "commented.h"
 #include "standard_conf.h"
 #include "system_defines.h"
 #include "populate_gsambad.h"
 #include "show_info.h"
 
 
-
+// Fixme, smb.conf path not completed etc.
 int conf_ok(gchar *file_path)
 {
     FILE *fp;
     long conf_size;
     char *line;
     int retval = 0;
+    int have_security = 0;
 
-    /* The configuration is ok if gsambad's settings has "show_conf_question: false" */
+    /* The configuration is ok if gsambad's settings
+       contains "show_conf_question: (no OR false)" */
     if((fp=fopen(file_path, "r"))==NULL)
     {
 	/* Return false */
 	return retval;
     }
-
     fseek(fp, 0, SEEK_END);
     conf_size = ftell(fp);
     rewind(fp);
-
     line = allocate(conf_size+1);
-      
+
     if( conf_size > 1 )
     while(fgets(line, conf_size, fp)!=NULL)
     {
+	/* Skip commented options */
+	if( commented(line) )
+	  continue;
+
 	if( strlen(line) > 5 )
 	{
-	    if( strstr(line, "show_conf_question:") && strstr(line, "false") )
+	    if( strstr(line, "show_conf_question:") 
+	    && (strstr(line, "false") || strstr(line, "no")) )
 	    {
 	        retval = 1;
 		break;
@@ -71,11 +76,44 @@ int conf_ok(gchar *file_path)
     fclose(fp);	
     free(line);
 
+
+    /* If the security option is missing the conf is still bad */
+    if((fp=fopen(SAMBA_CONF, "r"))==NULL)
+    {
+	return retval;
+    }
+    fseek(fp, 0, SEEK_END);
+    conf_size = ftell(fp);
+    rewind(fp);
+    line = allocate(conf_size+1);
+
+    if( conf_size > 1 )
+    while(fgets(line, conf_size, fp)!=NULL)
+    {
+	/* Skip commented options */
+	if( commented(line) )
+	  continue;
+    
+	if( strlen(line) > 5 )
+	{
+	    if( strstr(line, "security=") || strstr(line, "security =") )
+	    {
+	        have_security = 1;
+		break;
+	    }
+	}
+    }
+
+    if( ! have_security )
+      retval = 0;
+
+    fclose(fp);	
+    free(line);
+
     return retval;
 }
 
 
-
 void add_standard_conf(struct w *widgets)
 {
     /* This backs up the old configuration and adds the default configuration */
@@ -102,7 +140,6 @@ void add_standard_conf(struct w *widgets)
 	g_free(cmd);
     }
 
-
     /* Add the default configuration */
     if((fp=fopen(SAMBA_CONF, "w+"))==NULL)
     {
@@ -114,66 +151,116 @@ void add_standard_conf(struct w *widgets)
     buffer = allocate(100000);
 
     strcpy(buffer, "[global]\n");
-    strcat(buffer, "netbios name = samba24\n");
-    strcat(buffer, "server string = CAD architects, Stockholm, east 32nd st, 34th floor\n");
-    strcat(buffer, "workgroup = Workgroup\n"); /* use this as the domain to connect to */
-    strcat(buffer, "hosts allow = 127. 192.168.0.\n"); /* It would be great to automate this and the others */
-    strcat(buffer, "printcap name = /etc/printcap\n");
-    strcat(buffer, "load printers = yes\n");
-    strcat(buffer, "printing = cups\n");
-    strcat(buffer, "cups options = raw\n");
-    strcat(buffer, "guest account = smbguest\n");
-    strcat(buffer, "log file = /var/log/samba/samba.log\n");
-    strcat(buffer, "max log size = 1000\n");
+    strcat(buffer, "netbios name = Samba24\n");
+    strcat(buffer, "server string = CAD architects, Stockholm. East 32nd st, 34th floor\n");
+    strcat(buffer, "workgroup = Workgroup\n");
     strcat(buffer, "security = user\n");
+    /* Automatically adds ADS security level option: realm = domain.example.org */
+    strcat(buffer, "hosts allow = 127. 192.168.0.\n");
+    strcat(buffer, "interfaces = 127.0.0.1/8 192.168.0.0/24 \n");
+    strcat(buffer, "remote announce = 192.168.0.255\n");
+    strcat(buffer, "remote browse sync = 192.168.0.255\n");
+
+    info = g_strdup_printf("printcap name = %s/printcap\n", SYSCONFDIR);
+    strcat(buffer, info);
+    g_free(info);
+
+    strcat(buffer, "load printers = yes\n");
+    strcat(buffer, "cups options = raw\n");
+    strcat(buffer, "printing = cups\n"); /* Has no combo, no other options ? */
+    strcat(buffer, "guest account = smbguest\n");
+
+    info = g_strdup_printf("log file = %s/log/samba/samba.log\n", LOCALSTATEDIR);
+    strcat(buffer, info);
+    g_free(info);
+
+    strcat(buffer, "max log size = 1000\n");
+    strcat(buffer, "null passwords = no\n");
     strcat(buffer, "username level = 8\n");
     strcat(buffer, "password level = 8\n");
-
-    strcat(buffer, "username map = /etc/samba/smbusers\n");
-    strcat(buffer, "add user script = /usr/sbin/useradd -d /dev/null -g sambamachines -c 'Samba Machine Account' -s /dev/null -M '%u'\n");
-
-    strcat(buffer, "smb passwd file = /etc/samba/smbpasswd\n");
     strcat(buffer, "encrypt passwords = yes\n");
-    strcat(buffer, "unix password sync = Yes\n");
-    strcat(buffer, "passwd program = /usr/bin/passwd '%u'\n");
-    strcat(buffer, "passwd chat = *New*UNIX*password* %n\\n *ReType*new*UNIX*password* %n\\n *passwd:*all*authentication*tokens*updated*successfully*\\n\n");
-    strcat(buffer, "null passwords = no\n");
-
+    strcat(buffer, "unix password sync = yes\n");
     strcat(buffer, "socket options = TCP_NODELAY SO_RCVBUF=8192 SO_SNDBUF=8192\n");
-    strcat(buffer, "interfaces = 127.0.0.1/8 192.168.0.0/24 \n"); /* Automate this */
-    strcat(buffer, "remote browse sync = 192.168.0.255\n"); /* Automate this */
-    strcat(buffer, "remote announce = 192.168.0.255\n"); /* Automate this */
-
     strcat(buffer, "local master = no\n");
-    strcat(buffer, "os level = 33\n");
     strcat(buffer, "domain master = no\n");
     strcat(buffer, "preferred master = no\n");
-    strcat(buffer, "time server = no\n");
     strcat(buffer, "domain logons = no\n");
-
+    strcat(buffer, "os level = 33\n");
     strcat(buffer, "logon drive = m:\n");
     strcat(buffer, "logon home = \\\\%L\\homes\\%u\n");
     strcat(buffer, "logon path = \\\\%L\\profiles\\%u\n");
-
-    /* Groupname.bat script located in the netlogon directory */
     strcat(buffer, "logon script = %G.bat\n");
+    strcat(buffer, "time server = no\n");
     strcat(buffer, "name resolve order = wins lmhosts bcast\n");
     strcat(buffer, "wins support = no\n");
     strcat(buffer, "wins server =\n");
     strcat(buffer, "wins proxy = no\n");
     strcat(buffer, "dns proxy = no\n");
     strcat(buffer, "preserve case = no\n");
+    strcat(buffer, "client use spnego = no\n");
+    strcat(buffer, "client signing = no\n");
+    strcat(buffer, "client schannel = no\n");
+    strcat(buffer, "server signing = no\n");
+    strcat(buffer, "server schannel = no\n");
+    strcat(buffer, "nt pipe support = yes\n");
+    strcat(buffer, "nt status support = yes\n");
+    strcat(buffer, "allow trusted domains = no\n");
+    strcat(buffer, "obey pam restrictions = yes\n");
+    strcat(buffer, "enable spoolss = yes\n");
+    strcat(buffer, "client plaintext auth = no\n");
+    strcat(buffer, "disable netbios = no\n");
+    strcat(buffer, "follow symlinks = no\n");
+    strcat(buffer, "update encrypted = yes\n");
+    strcat(buffer, "pam password change = no\n");
+    strcat(buffer, "passwd chat timeout = 120\n");
+    strcat(buffer, "hostname lookups = no\n");
 
-// These 3 are not used
-    strcat(buffer, ";  short preserve case = no\n");
-    strcat(buffer, ";  default case = lower\n");
-    strcat(buffer, ";  case sensitive = no\n");
-    strcat(buffer, "winbind use default domain = yes\n");
+    info = g_strdup_printf("username map = %s/samba/smbusers\n", SYSCONFDIR);
+    strcat(buffer, info);
+    g_free(info);
+
+    info = g_strdup_printf("smb passwd file = %s/samba/smbpasswd\n", SYSCONFDIR);
+    strcat(buffer, info);
+    g_free(info);
+
+    strcat(buffer, "passwd program = /usr/bin/passwd '%u'\n");
+
+/* Doesnt seem to work    info = g_strdup_printf("root directory = %s/samba/root\n", LOCALSTATEDIR);
+    strcat(buffer, info);
+    g_free(info);
+*/
+    strcat(buffer, "passwd chat = *New*password* %n\\n *ReType*new*password* %n\\n *passwd*changed*\\n\n");
+    strcat(buffer, "add user script = /usr/sbin/useradd -d /dev/null -c 'Samba User Account' -s /dev/null '%u'\n");
+    strcat(buffer, "add user to group script=/usr/sbin/useradd -d /dev/null -c 'Samba User Account' -s /dev/null -g '%g' '%u'\n");
+    strcat(buffer, "add group script = /usr/sbin/groupadd '%g'\n");
+    strcat(buffer, "delete user script = /usr/sbin/userdel '%u'\n");
+    strcat(buffer, "delete user from group script = /usr/sbin/userdel '%u' '%g'\n");
+    strcat(buffer, "delete group script = /usr/sbin/groupdel '%g'\n");
+    strcat(buffer, "add machine script = /usr/sbin/useradd -d /dev/null -g sambamachines -c 'Samba Machine Account' -s /dev/null -M '%u'\n");
+    strcat(buffer, "machine password timeout = 120\n");
     strcat(buffer, "idmap uid = 16777216-33554431\n");
     strcat(buffer, "idmap gid = 16777216-33554431\n");
     strcat(buffer, "template shell = /dev/null\n");
 
-    
+    /* Winbindd stuff */
+    strcat(buffer, "winbind use default domain = yes\n");
+    strcat(buffer, "winbind separator = @\n");
+    strcat(buffer, "winbind cache time = 360\n");
+    strcat(buffer, "winbind trusted domains only = yes\n");
+    strcat(buffer, "winbind nested groups = no\n");
+    strcat(buffer, "winbind nss info = no\n");
+    strcat(buffer, "winbind refresh tickets = no\n");
+    strcat(buffer, "winbind offline logon = no\n");
+
+/*
+;Begin Not working ???
+;announce as = win95
+;announce version = 42
+;FIXME COMBOBOX: announce as = "NT Server"
+;|NT|NT Server|NT Workstation|win95|WfW|
+;End Not working ???
+*/
+
 
     /* Shared home directories */
     strcat(buffer, "\n");
@@ -205,11 +292,15 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "locking = no\n");
 
 
-    /* Profiles are created automatically for each user, windows adds the files */
+    /* Profiles are created automatically for each user, clients adds the files */
     strcat(buffer, "\n");
     strcat(buffer, "[profiles]\n"); /* This must be writable */
     strcat(buffer, "comment = User Profiles\n");
-    strcat(buffer, "path = /home/profiles\n");
+
+    strcat(buffer, "path = ");
+    strcat(buffer, LOCALSTATEDIR);
+    strcat(buffer, "/samba/profiles\n");
+
     strcat(buffer, "read only = no\n");
     strcat(buffer, "available = yes\n");
     strcat(buffer, "browseable = no\n");
@@ -225,7 +316,9 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "\n");
     strcat(buffer, "[printers]\n");
     strcat(buffer, "comment = All Printers\n");
-    strcat(buffer, "path = /var/spool/samba\n");
+    info = g_strdup_printf("path = %s/spool/samba\n", LOCALSTATEDIR);
+    strcat(buffer, info);
+    g_free(info);
     strcat(buffer, "browseable = yes\n");
     strcat(buffer, "writable = no\n");
     strcat(buffer, "guest ok = no\n");
@@ -267,13 +360,12 @@ void add_standard_conf(struct w *widgets)
 
     populate_gsambad(widgets);
 
-
-    /* Create directories default directories */
-    cmd = g_strdup_printf("%s /home/netlogon /home/pdf-documents /home/profiles/root /var/log/samba\n", "mkdir -p");
+    /* Create default directories */
+    cmd = g_strdup_printf("mkdir -p /home/netlogon /home/pdf-documents %s/samba/profiles/root %s/log/samba\n", LOCALSTATEDIR, LOCALSTATEDIR);
     if((fp=popen(cmd, "w"))==NULL)
     {
         perror("popen");
-        info = g_strdup_printf(_("Failed to create directories:\n%s\n"), "/home/netlogon, /home/pdf-documents and /home/profiles/root");
+        info = g_strdup_printf(_("Failed to create directories:\n%s\n"), "/home/netlogon, /home/pdf-documents and /var/samba/profiles/root");
         show_info(info);
 	g_free(info);
         g_free(cmd);
@@ -297,11 +389,11 @@ void add_standard_conf(struct w *widgets)
     g_free(cmd);
 
     /* Chown the profiles directory */
-    cmd = g_strdup_printf("%s /home/profiles /home/pdf-documents\n", "chown root:nobody");
+    cmd = g_strdup_printf("chown root:nobody %s/samba/profiles /home/pdf-documents\n", LOCALSTATEDIR);
     if((fp=popen(cmd, "w"))==NULL)
     {
         perror("popen");
-        info = g_strdup_printf(_("Failed chowning the directories: %s\n"), "/home/profiles /home/pdf-documents");
+        info = g_strdup_printf(_("Failed chowning the directories: %s\n"), "/var/samba/profiles /home/pdf-documents");
         show_info(info);
 	g_free(info);
         g_free(cmd);
@@ -311,11 +403,11 @@ void add_standard_conf(struct w *widgets)
     g_free(cmd);
 
     /* Chmod the profiles directory */
-    cmd = g_strdup_printf("%s /home/profiles\n", "chmod 775");
+    cmd = g_strdup_printf("chmod 755 %s/samba/profiles\n", LOCALSTATEDIR);
     if((fp=popen(cmd, "w"))==NULL)
     {
         perror("popen");
-        info = g_strdup_printf(_("Failed chmodding directory: %s\n"), "/home/profiles");
+        info = g_strdup_printf(_("Failed chmodding directory: %s\n"), "/var/samba/profiles");
         show_info(info);
 	g_free(info);
         g_free(cmd);
@@ -338,17 +430,26 @@ void add_standard_conf(struct w *widgets)
     pclose(fp);
     g_free(cmd);
 
-    
+    /* Create the samba root users home directory */
+    cmd = g_strdup_printf("mkdir -p %s/samba/root\n", LOCALSTATEDIR);
+    if((fp=popen(cmd, "w"))==NULL)
+    {
+        perror("popen");
+        info = g_strdup_printf(_("Failed to create directory: %s/%s\n"), LOCALSTATEDIR, "/samba/root");
+        show_info(info);
+	g_free(info);
+        g_free(cmd);
+        return;
+    }
+    pclose(fp);
+    g_free(cmd);
 
     /* Fixme: add username mappings to /etc/samba/smbusers */
     // root = administrator
     // nobody = guest
 
-
-    /* Run commands after standard_users to update samba group mappings: */
-    /* FIXME, move to domain management tab!!! */    
-
     // net groupmap modify ntgroup="Domain Admins" unixgroup=root
+    // net groupmap modify ntgroup="Administrators" unixgroup=root
     // net groupmap modify ntgroup="Power Users" unixgroup=sys
     // net groupmap modify ntgroup="Domain Users" unixgroup=users
     // net groupmap modify ntgroup="Domain Guests" unixgroup=nobody
