@@ -1,5 +1,6 @@
-/* GSAMBAD, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 Magnus Loef <magnus-swe@telia.com> 
+/*
+ * GProFTPD - A GTK+ frontend for the ProFTPD standalone server.
+ * Copyright (C) 2001 - 2006 Magnus Loef (Magnus-swe) <magnus-swe@telia.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,14 +16,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
  *
-*/
+ */
 
 
-#ifndef GSAMBAD_status_update_H
-#   define GSAMBAD_status_update_H
+#ifndef status_update_H
+#   define status_update_H
 
 extern struct w *widgets;
 
+char * process_running(char process[1024]); //, char extmatch[1024]);
+
 int status_update(struct w *widgets);
 
 #endif
